@@ -56,6 +56,9 @@ FAILEDOPERATION_COMPONENTCLIENTUNPACK = 'FailedOperation.ComponentClientUnpack'
 # 请求(http请求)其他云服务失败。
 FAILEDOPERATION_COMPONENTCLINETHTTP = 'FailedOperation.ComponentClinetHttp'
 
+# 创建CLS客户端失败。
+FAILEDOPERATION_CREATECLSCLIENT = 'FailedOperation.CreateClsClient'
+
 # 创建CLS采集配置失败。
 FAILEDOPERATION_CREATECLSCONFIG = 'FailedOperation.CreateClsConfig'
 
@@ -461,6 +464,9 @@ RESOURCEINUSE_RESOURCEEXISTALREADY = 'ResourceInUse.ResourceExistAlready'
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
+# CVM资源不足。
+RESOURCEINSUFFICIENT_SPECIFIEDINSTANCETYPE = 'ResourceInsufficient.SpecifiedInstanceType'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
